#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2024-01-10
# File  : fritzbox_smarthome_humidity.py (check plugin)
#
#

from typing import Dict

from cmk.base.plugins.agent_based.agent_based_api.v1 import Result, Service, State, register
from cmk.base.plugins.agent_based.agent_based_api.v1.type_defs import CheckResult, DiscoveryResult
from cmk.base.plugins.agent_based.utils.humidity import check_humidity
from cmk.base.plugins.agent_based.utils.fritzbox_smarthome import AvmSmartHomeDevice


def discovery_fritzbox_smarthome_humidity_single(
        section: AvmSmartHomeDevice | Dict[str, AvmSmartHomeDevice]
) -> DiscoveryResult:
    if isinstance(section, AvmSmartHomeDevice):
        if section.humidity:
            yield Service()


def discovery_fritzbox_smarthome_humidity_multiple(
        section: AvmSmartHomeDevice | Dict[str, AvmSmartHomeDevice]
) -> DiscoveryResult:
    if not isinstance(section, AvmSmartHomeDevice):
        for device_id, device in section.items():
            if device.humidity:
                yield Service(item=str(device_id))


def check_fritzbox_smarthome_humidity_single(
        params, section: AvmSmartHomeDevice | Dict[str, AvmSmartHomeDevice]
) -> CheckResult:
    if not isinstance(section, AvmSmartHomeDevice) or not section.humidity:
        return
    print(params)
    if section.humidity.rel_humidity:
        yield from check_humidity(
            humidity=section.humidity.rel_humidity,
            params=params.get('auto-migration-wrapper-key'),
        )


def check_fritzbox_smarthome_humidity_multiple(
        item, params, section: AvmSmartHomeDevice | Dict[str, AvmSmartHomeDevice]
) -> CheckResult:
    if isinstance(section, Dict):
        try:
            yield from check_fritzbox_smarthome_humidity_single(params, section[item])
        except KeyError:
            return


register.check_plugin(
    name='fritzbox_smarthome_humidity_single',
    service_name='Humidity',
    sections=['fritzbox_smarthome'],
    discovery_function=discovery_fritzbox_smarthome_humidity_single,
    check_function=check_fritzbox_smarthome_humidity_single,
    check_ruleset_name='single_humidity',
    check_default_parameters={}
)

register.check_plugin(
    name='fritzbox_smarthome_humidity',
    service_name='Smarthome Humidity %s',
    sections=['fritzbox_smarthome'],
    discovery_function=discovery_fritzbox_smarthome_humidity_multiple,
    check_function=check_fritzbox_smarthome_humidity_multiple,
    check_ruleset_name='humidity',
    check_default_parameters={}
)
