#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2023-12-28
# File  : fritzbox_smarthome.py (WATO check plugin)
#


from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Alternative,
    Dictionary,
    Integer,
    MonitoringState,
    Tuple,
    TextInput,
)
from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithItem,
    CheckParameterRulespecWithoutItem,
    RulespecGroupCheckParametersApplications,
    rulespec_registry,
)


def _parameter_valuespec_fritzbox_smarthome():
    return Dictionary(
        title=_('Parameter'),
        elements=[
            ('present',
             MonitoringState(
                 title=_('Monitoring state for offline devices'),
                 default_value=1,
             )),
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name="fritzbox_smarthome_single",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_fritzbox_smarthome,
        title=lambda: _('Fritz!Box Smarthome Devices')
    )
)

rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name="fritzbox_smarthome_multiple",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_fritzbox_smarthome,
        title=lambda: _('Fritz!Box Smarthome Devices (with Device-ID)'),
        item_spec=lambda: TextInput(title=_('Device-ID')),
    )
)


def _parameter_valuespec_fritzbox_smarthome_thermostat():
    return Dictionary(
        title=_('Parameter'),
        elements=[
            ('deviation',
             Tuple(
                 title=_('Deviation from target temperature'),
                 help=_('Deviation form target temperature in °C'),
                 elements=[
                     Integer(title=_('Warning'), default_value=3, unit=_('°C')),
                     Integer(title=_('Critical'), default_value=5, unit=_('°C')),
                 ])),
            ('state_off',
             MonitoringState(
                 title=_('Monitoring state if thermostat is off'),
                 default_value=0,
             )),
            ('state_windows_open',
             MonitoringState(
                 title=_('Monitoring state if windows open active'),
                 default_value=1,
             )),
            ('state_boost_mode',
             MonitoringState(
                 title=_('Monitoring state if boost mode active'),
                 default_value=1,
             )),
            ('state_on_error',
             MonitoringState(
                 title=_('Monitoring state on error'),
                 default_value=1,
             )),
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name="fritzbox_smarthome_thermostat_single",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_fritzbox_smarthome_thermostat,
        title=lambda: _('Fritz!Box Smarthome Thermostat'),
    )
)


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name="fritzbox_smarthome_thermostat_multiple",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_fritzbox_smarthome_thermostat,
        title=lambda: _('Fritz!Box Smarthome Thermostat (with Device-ID)'),
        item_spec=lambda: TextInput(title=_('Device-ID')),
    )
)


def _parameter_valuespec_fritzbox_smarthome_battery():
    return Dictionary(
        title=_('Parameter'),
        elements=[
            ('battery_low',
             MonitoringState(
                 title=_('Monitoring state on low battery'),
                 default_value=2,
             )),
            ('levels_lower',
             Tuple(
                 title=_('Lower levels for battery'),
                 elements=[
                     Integer(title=_('Warning below'), default_value=50, unit=_('%')),
                     Integer(title=_('Critical below'), default_value=40, unit=_('%')),
                 ])),
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name="fritzbox_smarthome_battery_single",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_fritzbox_smarthome_battery,
        title=lambda: _('Fritz!Box Smarthome battery')
    )
)

rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name="fritzbox_smarthome_battery_multiple",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_fritzbox_smarthome_battery,
        title=lambda: _('Fritz!Box Smarthome battery (with Device-ID)'),
        item_spec=lambda: TextInput(title=_('Device-ID')),
    )
)


def _parameter_valuespec_fritzbox_smarthome_sensor():
    return Dictionary(
        title=_('Parameter'),
        elements=[
            ('state',
             Alternative(
                 title=_('Sensor state'),
                 elements=[
                     Dictionary(
                         title=_('Sensor closed'),
                         optional_keys=False,
                         elements=[
                             ('closed',
                              MonitoringState(
                                  title=_('Monitoring state (closed)'),
                                  default_value=0,
                              )),
                         ]),
                     Dictionary(
                         title=_('Sensor open'),
                         optional_keys=False,
                         elements=[
                             ('open',
                              MonitoringState(
                                  title=_('Monitoring state (open)'),
                                  default_value=0,
                              ))
                         ]),
                 ]
             )),
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name="fritzbox_smarthome_sensor_single",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_fritzbox_smarthome_sensor,
        title=lambda: _('Fritz!Box Smarthome Sensor')
    )
)

rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name="fritzbox_smarthome_sensor_multiple",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_fritzbox_smarthome_sensor,
        title=lambda: _('Fritz!Box Smarthome Sensor (with Device-ID)'),
        item_spec=lambda: TextInput(title=_('Device-ID')),
    )
)
